@@ -2,7 +2,7 @@
 
 import socketio,pyperclip,time,argparse
 
-__version__ = "v0.0.22"
+__version__ = "v0.0.23"
 # standard Python
 sio = socketio.Client()
 @sio.event
@@ -37,14 +37,13 @@ def main():
 
     curr_clip = pyperclip.paste()
 
-    while pyperclip.waitForNewPaste():
+    while True:
         new_clip = pyperclip.paste()
-        print("New clip: " + new_clip)
-
         if new_clip != curr_clip:
             if not new_clip.startswith("file:///"):
                 sio.emit('sync',{"data":new_clip, "room":room})
             curr_clip = new_clip
+        time.sleep(0.5)
 def cli() -> None:
     try:
         main()
